
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#include "shumate.h"
/* enumerations from "shumate-file-cache.h" */
GType
shumate_file_cache_error_get_type (void)
{
	static GType etype = 0;
	if (G_UNLIKELY (etype == 0)) {
		static const GEnumValue values[] = {
			{ SHUMATE_FILE_CACHE_ERROR_FAILED, "SHUMATE_FILE_CACHE_ERROR_FAILED", "failed" },
			{ 0, NULL, NULL }
		};
		etype = g_enum_register_static (g_intern_static_string ("ShumateFileCacheError"), values);
	}
	return etype;
}
/* enumerations from "shumate-map-source.h" */
GType
shumate_map_projection_get_type (void)
{
	static GType etype = 0;
	if (G_UNLIKELY (etype == 0)) {
		static const GEnumValue values[] = {
			{ SHUMATE_MAP_PROJECTION_MERCATOR, "SHUMATE_MAP_PROJECTION_MERCATOR", "mercator" },
			{ 0, NULL, NULL }
		};
		etype = g_enum_register_static (g_intern_static_string ("ShumateMapProjection"), values);
	}
	return etype;
}
/* enumerations from "shumate-scale.h" */
GType
shumate_unit_get_type (void)
{
	static GType etype = 0;
	if (G_UNLIKELY (etype == 0)) {
		static const GEnumValue values[] = {
			{ SHUMATE_UNIT_BOTH, "SHUMATE_UNIT_BOTH", "both" },
			{ SHUMATE_UNIT_METRIC, "SHUMATE_UNIT_METRIC", "metric" },
			{ SHUMATE_UNIT_IMPERIAL, "SHUMATE_UNIT_IMPERIAL", "imperial" },
			{ 0, NULL, NULL }
		};
		etype = g_enum_register_static (g_intern_static_string ("ShumateUnit"), values);
	}
	return etype;
}
/* enumerations from "shumate-tile-downloader.h" */
GType
shumate_tile_downloader_error_get_type (void)
{
	static GType etype = 0;
	if (G_UNLIKELY (etype == 0)) {
		static const GEnumValue values[] = {
			{ SHUMATE_TILE_DOWNLOADER_ERROR_FAILED, "SHUMATE_TILE_DOWNLOADER_ERROR_FAILED", "failed" },
			{ SHUMATE_TILE_DOWNLOADER_ERROR_BAD_RESPONSE, "SHUMATE_TILE_DOWNLOADER_ERROR_BAD_RESPONSE", "bad-response" },
			{ SHUMATE_TILE_DOWNLOADER_ERROR_COULD_NOT_CONNECT, "SHUMATE_TILE_DOWNLOADER_ERROR_COULD_NOT_CONNECT", "could-not-connect" },
			{ SHUMATE_TILE_DOWNLOADER_ERROR_MALFORMED_URL, "SHUMATE_TILE_DOWNLOADER_ERROR_MALFORMED_URL", "malformed-url" },
			{ SHUMATE_TILE_DOWNLOADER_ERROR_OFFLINE, "SHUMATE_TILE_DOWNLOADER_ERROR_OFFLINE", "offline" },
			{ 0, NULL, NULL }
		};
		etype = g_enum_register_static (g_intern_static_string ("ShumateTileDownloaderError"), values);
	}
	return etype;
}
/* enumerations from "shumate-tile.h" */
GType
shumate_state_get_type (void)
{
	static GType etype = 0;
	if (G_UNLIKELY (etype == 0)) {
		static const GEnumValue values[] = {
			{ SHUMATE_STATE_NONE, "SHUMATE_STATE_NONE", "none" },
			{ SHUMATE_STATE_LOADING, "SHUMATE_STATE_LOADING", "loading" },
			{ SHUMATE_STATE_LOADED, "SHUMATE_STATE_LOADED", "loaded" },
			{ SHUMATE_STATE_DONE, "SHUMATE_STATE_DONE", "done" },
			{ 0, NULL, NULL }
		};
		etype = g_enum_register_static (g_intern_static_string ("ShumateState"), values);
	}
	return etype;
}
/* enumerations from "shumate-vector-reader-iter.h" */
GType
shumate_geometry_type_get_type (void)
{
	static GType etype = 0;
	if (G_UNLIKELY (etype == 0)) {
		static const GEnumValue values[] = {
			{ SHUMATE_GEOMETRY_TYPE_UNKNOWN, "SHUMATE_GEOMETRY_TYPE_UNKNOWN", "unknown" },
			{ SHUMATE_GEOMETRY_TYPE_POINT, "SHUMATE_GEOMETRY_TYPE_POINT", "point" },
			{ SHUMATE_GEOMETRY_TYPE_MULTIPOINT, "SHUMATE_GEOMETRY_TYPE_MULTIPOINT", "multipoint" },
			{ SHUMATE_GEOMETRY_TYPE_LINESTRING, "SHUMATE_GEOMETRY_TYPE_LINESTRING", "linestring" },
			{ SHUMATE_GEOMETRY_TYPE_MULTILINESTRING, "SHUMATE_GEOMETRY_TYPE_MULTILINESTRING", "multilinestring" },
			{ SHUMATE_GEOMETRY_TYPE_POLYGON, "SHUMATE_GEOMETRY_TYPE_POLYGON", "polygon" },
			{ SHUMATE_GEOMETRY_TYPE_MULTIPOLYGON, "SHUMATE_GEOMETRY_TYPE_MULTIPOLYGON", "multipolygon" },
			{ 0, NULL, NULL }
		};
		etype = g_enum_register_static (g_intern_static_string ("ShumateGeometryType"), values);
	}
	return etype;
}
/* enumerations from "shumate-vector-renderer.h" */
GType
shumate_style_error_get_type (void)
{
	static GType etype = 0;
	if (G_UNLIKELY (etype == 0)) {
		static const GEnumValue values[] = {
			{ SHUMATE_STYLE_ERROR_FAILED, "SHUMATE_STYLE_ERROR_FAILED", "failed" },
			{ SHUMATE_STYLE_ERROR_MALFORMED_STYLE, "SHUMATE_STYLE_ERROR_MALFORMED_STYLE", "malformed-style" },
			{ SHUMATE_STYLE_ERROR_UNSUPPORTED_LAYER, "SHUMATE_STYLE_ERROR_UNSUPPORTED_LAYER", "unsupported-layer" },
			{ SHUMATE_STYLE_ERROR_INVALID_EXPRESSION, "SHUMATE_STYLE_ERROR_INVALID_EXPRESSION", "invalid-expression" },
			{ SHUMATE_STYLE_ERROR_SUPPORT_OMITTED, "SHUMATE_STYLE_ERROR_SUPPORT_OMITTED", "support-omitted" },
			{ SHUMATE_STYLE_ERROR_UNSUPPORTED, "SHUMATE_STYLE_ERROR_UNSUPPORTED", "unsupported" },
			{ 0, NULL, NULL }
		};
		etype = g_enum_register_static (g_intern_static_string ("ShumateStyleError"), values);
	}
	return etype;
}
/* enumerations from "shumate-vector-value.h" */
GType
shumate_vector_value_type_get_type (void)
{
	static GType etype = 0;
	if (G_UNLIKELY (etype == 0)) {
		static const GEnumValue values[] = {
			{ SHUMATE_VECTOR_VALUE_TYPE_NULL, "SHUMATE_VECTOR_VALUE_TYPE_NULL", "null" },
			{ SHUMATE_VECTOR_VALUE_TYPE_NUMBER, "SHUMATE_VECTOR_VALUE_TYPE_NUMBER", "number" },
			{ SHUMATE_VECTOR_VALUE_TYPE_BOOLEAN, "SHUMATE_VECTOR_VALUE_TYPE_BOOLEAN", "boolean" },
			{ SHUMATE_VECTOR_VALUE_TYPE_STRING, "SHUMATE_VECTOR_VALUE_TYPE_STRING", "string" },
			{ SHUMATE_VECTOR_VALUE_TYPE_COLOR, "SHUMATE_VECTOR_VALUE_TYPE_COLOR", "color" },
			{ SHUMATE_VECTOR_VALUE_TYPE_ARRAY, "SHUMATE_VECTOR_VALUE_TYPE_ARRAY", "array" },
			{ SHUMATE_VECTOR_VALUE_TYPE_RESOLVED_IMAGE, "SHUMATE_VECTOR_VALUE_TYPE_RESOLVED_IMAGE", "resolved-image" },
			{ SHUMATE_VECTOR_VALUE_TYPE_FORMATTED_STRING, "SHUMATE_VECTOR_VALUE_TYPE_FORMATTED_STRING", "formatted-string" },
			{ SHUMATE_VECTOR_VALUE_TYPE_COLLATOR, "SHUMATE_VECTOR_VALUE_TYPE_COLLATOR", "collator" },
			{ 0, NULL, NULL }
		};
		etype = g_enum_register_static (g_intern_static_string ("ShumateVectorValueType"), values);
	}
	return etype;
}

/* Generated data ends here */

